@@ -1,13 +1,12 @@
-{-# LANGUAGE
-CPP,
-FlexibleInstances,
-FlexibleContexts,
-UndecidableInstances,
-RankNTypes,
-ScopedTypeVariables,
-MonoLocalBinds,
-Trustworthy
-  #-}
+{-# LANGUAGE CPP #-}
+{-# LANGUAGE FlexibleInstances #-}
+{-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE UndecidableInstances #-}
+{-# LANGUAGE RankNTypes #-}
+{-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE MonoLocalBinds #-}
+{-# LANGUAGE ConstraintKinds #-}
+{-# LANGUAGE Trustworthy #-}
 
 
 {- |
@@ -587,7 +586,7 @@ infixl 8 ^?
 {- |
 ('^?!') is an unsafe variant of ('^?') – instead of using 'Nothing' to indicate that there were no elements returned, it throws an exception.
 -}
-(^?!) :: s -> Getting (Endo a) s a -> a
+(^?!) :: HasCallStack => s -> Getting (Endo a) s a -> a
 s ^?! l = foldrOf l const (error "(^?!): empty Fold") s
 {-# INLINE (^?!) #-}
 
@@ -930,7 +929,7 @@ However, it won't fail if you are merely setting the value:
 
 >>> [] & singular each %~ negate
 -}
-singular :: Traversal s t a a -> Lens s t a a
+singular :: HasCallStack => Traversal s t a a -> Lens s t a a
 singular l afb s = case ins b of
   (w:ws) -> unsafeOuts b . (:ws) <$> afb w
   []     -> unsafeOuts b . return <$>
@@ -969,7 +968,7 @@ failing left right afb s = case pins b of
 infixl 5 `failing`
 
 {- |
-'filtered' is a traversal that filters elements “passing” thru it:
+'filtered' is a traversal that filters elements “passing” through it:
 
 >>> (1,2,3,4) ^.. each
 [1,2,3,4]
@@ -1032,7 +1031,7 @@ pairedWithEvens :: 'Traversal' [(Int, a)] [(Int, b)] a b
 pairedWithEvens = 'each' '.' 'filtered' ('even' '.' 'fst') '.' '_2'
 @
 
-Since you can't do anything with the 1st components thru this traversal, the following holds for any @f@ and @g@:
+Since you can't do anything with the 1st components through this traversal, the following holds for any @f@ and @g@:
 
 @
 'over' pairedWithEvens f '.' 'over' pairedWithEvens g = 'over' pairedWithEvens (f '.' g)
